@@ -103,11 +103,11 @@ class Client(object):
     def get_colab_auth_from_drive(self, usernameDriveAuth):
         user_auth = None
         try:
-            # from google.colab import auth
+            from google.colab import drive
             # auth.authenticate_user()
-            gauth = GoogleAuth()
-            gauth.credentials = GoogleCredentials.get_application_default()
-            drive = GoogleDrive(gauth)
+            # gauth = GoogleAuth()
+            # gauth.credentials = GoogleCredentials.get_application_default()
+            # drive = GoogleDrive(auth)
 
             file_list = drive.ListFile().GetList()
             user_auth = None
@@ -120,7 +120,7 @@ class Client(object):
                     user_auth = f_.GetContentString(fname)
 
                     self._username = usernameDriveAuth
-                    self._password = json.loads(user_auth['password'])
+                    self._password = json.loads(user_auth)['password']
 
                     break;
 
